from setuptools import setup, find_packages

setup(
    name='mess_client_vasiljev',
    version='0.0.1',
    description='mess_client_vasiljev',
    author='Vasiljev Serghei',
    author_email='gb@mail.ru',
    zip_safe=False,
    install_requires=[
        'alabaster',
        'Babel',
        'bandit',
        'certifi',
        'chardet',
        'charset-normalizer',
        'click',
        'colorama',
        'docutils',
        'dparse',
        'flake8',
        'gitdb',
        'GitPython',
        'greenlet',
        'idna',
        'imagesize',
        'Jinja2',
        'markdown-it-py',
        'MarkupSafe',
        'mccabe',
        'mdurl',
        'packaging',
        'pbr',
        'pycodestyle',
        'pycryptodome',
        'pyflakes',
        'Pygments',
        'pyparsing',
        'PyQt5',
        'PyQt5-Qt5',
        'PyQt5-sip',
        'PyQt5-stubs',
        'PyYAML',
        'requests',
        'rich',
        'ruamel.yaml',
        'ruamel.yaml.clib',
        'safety',
        'smmap',
        'snowballstemmer',
        'Sphinx',
        'sphinxcontrib-applehelp',
        'sphinxcontrib-devhelp',
        'sphinxcontrib-htmlhelp',
        'sphinxcontrib-jsmath',
        'sphinxcontrib-qthelp',
        'sphinxcontrib-serializinghtml',
        'SQLAlchemy',
        'stevedore',
        'tabulate',
        'typing_extensions',
        'urllib3',
        'sqlite3',
    ]
)